#
# spec file for package r128gain
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2020-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           r128gain
Version:        1.0.7
Release:        2.8
Summary:        Fast audio loudness (ReplayGain / R128) scanner & tagger
License:        LGPL-2.0-only
Group:          Productivity/Multimedia/Sound/Players
URL:            https://github.com/desbma/r128gain
Source:         https://github.com/desbma/r128gain/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-setuptools
Requires:       python3-crcmod >= 1.7
Requires:       python3-ffmpeg-python >= 0.2
Requires:       python3-mutagen >= 1.43
Requires:       python3-tqdm >= 4.28.1
BuildArch:      noarch

%description
Fast audio loudness (ReplayGain / R128) scanner & tagger.

%prep
%setup -q
sed -i -e '/^#!\//, 1d'  r128gain/__*

%build
%python3_build

%install
%python3_install
%fdupes %{buildroot}%{python3_sitelib}

#%%check
#disable tests since a network connection is required to download mediafiles from wikimedia

%files
%license LICENSE
%doc README.md
%{_bindir}/r128gain
%{python3_sitelib}/r128gain*

%changelog
* Thu Dec 21 2023 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded Requires on python3-future.
* Sat Mar 25 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.7
  * feat: warn if input is not a directory in recursive mode.
  * refactor: reduce get_r128_loudness complexity.
  * fix: mypy pre-commit hook error.
  * fix: workaround ffmpeg ebur128 filter early stop with concat.
  * fix: improve ffmpeg ebur128 output parsing.
  * fix: wrong replaygain sample peak calculation for non standard
    sample rates.
  * fix: don't map ffmpeg filter output.
  * feat: make progress output persistant.
  * feat: log filter script
- Update to version 1.0.6
  * no functional changes
- Update to version 1.0.5
  * no functional changes
* Sun Oct 24 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.4:
  * Drop Python 3.5 support
  * Add typing annotations
  * Fix AAC file support
* Mon Sep 21 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.3:
  * Fix race causing futures to be forgotten too early
  * Read/write MP4 tags using lowercase key format (fixes #22)
* Wed Jun 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.2:
  * Better handling of non unicode filenames
  * Pass ffmpeg verbosity flags
* Sun Feb  2 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.1
  * Logging fix
  * Improve & refractor recursive progress report
* Tue Jan 14 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.0.0
